@@ -8,6 +8,6 @@ test_that("NAs turn in NULLs", {
   )
   sql_df <- sqlData(ANSI(), df)
 
-  expect_equal(sql_df$x, c("1", "NULL"))
-  expect_equal(sql_df$y, c("'a'", "NULL"))
+  expect_equal(sql_df$x, SQL(c("1", "NULL")))
+  expect_equal(sql_df$y, SQL(c("'a'", "NULL")))
 })
